@@ -9,7 +9,7 @@ from . import forms
 
 class AuthorizeNetBackend(object):
     def __init__(self, api_class=None, recurring_api_class=None,
-            settings=None):
+            settings=None, testing=None):
         if api_class is None:
             api_class = aim.Api
         self.api_class = api_class
@@ -19,14 +19,18 @@ class AuthorizeNetBackend(object):
         if recurring_api_class is None:
             recurring_api_class = arb.Api
         self.recurring_api_class = recurring_api_class
+        if testing is None:
+            testing = getattr(self.settings, "ARMSTRONG_DONATIONS_TESTING", False)
+        self.testing = testing
 
     def get_api(self):
         return self.api_class(self.settings.AUTHORIZE["LOGIN"],
-                self.settings.AUTHORIZE["KEY"], delimiter=u"|")
+                self.settings.AUTHORIZE["KEY"], delimiter=u"|",
+                is_test=self.testing)
 
     def get_recurring_api(self):
         return self.recurring_api_class(self.settings.AUTHORIZE["LOGIN"],
-                self.settings.AUTHORIZE["KEY"])
+                self.settings.AUTHORIZE["KEY"], is_test=self.testing)
 
     def get_form_class(self):
         return forms.AuthorizeDonationForm
@@ -57,6 +61,8 @@ class AuthorizeNetBackend(object):
             "total_occurrences": donation.donation_type.repeat,
             "start_date": start_date,
         })
+        if self.testing:
+            data["test_request"] = u"TRUE"
         response = api.create_subscription(**data)
         status = response["messages"]["result_code"]["text_"] == u"Ok"
         return {
@@ -79,6 +85,8 @@ class AuthorizeNetBackend(object):
             "state": donor.address.state,
             "zip": donor.address.zipcode,
         })
+        if self.testing:
+            data["test_request"] = u"TRUE"
         response = api.transaction(**data)
         status = response["reason_code"] == u"1"
         return {
